@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
+
 from astypes import Type
 
 
@@ -11,10 +12,9 @@ class FSig:
     return_type: Type
 
     @property
-    def imports(self) -> set[str]:
+    def imports(self) -> frozenset[str]:
         return self.return_type.imports
 
     @property
-    def stub(self) -> str:
-        rtype = self.return_type.annotation
-        return f'def {self.name}({self.args}) -> {rtype}: ...'
+    def annotation(self) -> str:
+        return self.return_type.annotation
